import { useAjax } from '@/Hook/useAjax';
import { getRoleIpDetailListApi } from '@/services/gsData';
import { Modal, Table } from 'antd';
import React, { useEffect, useState } from 'react';

const LoginIpDetails: React.FC<{ roleId: any, icon?: React.ReactNode }> = ({ roleId, icon }) => {

    /*********************************/
    const [queryForm, setQueryForm] = useState<{ pageSize: number, pageNum: number }>({ pageNum: 1, pageSize: 10 })
    const [visible, setVisible] = useState<boolean>(false)
    const getRoleIpDetailList = useAjax((params) => getRoleIpDetailListApi(params))
    /*********************************/

    useEffect(() => {
        if (visible) {
            getRoleIpDetailList.run({ roleId, ...queryForm })
        }
    }, [roleId, visible, queryForm])

    return <>
        <a onClick={() => setVisible(true)}>{icon}</a>
        {visible && <Modal
            title={<strong>登录IP(角色ID：{roleId})</strong>}
            visible={visible}
            onCancel={() => setVisible(false)}
            footer={null}
            width={700}
        >
            <Table
                columns={[
                    {
                        title: 'IP',
                        dataIndex: 'ip',
                        key: 'ip',
                    },
                    {
                        title: 'IP角色数量',
                        dataIndex: 'ipRoleCount',
                        key: 'ipRoleCount',
                    }
                ]}
                rowKey={'ip'}
                dataSource={getRoleIpDetailList?.data?.records}
                loading={getRoleIpDetailList?.loading}
                size="small"
                bordered
                pagination={{
                    total: getRoleIpDetailList?.data?.total,
                    pageSize: getRoleIpDetailList?.data?.size,
                    current: getRoleIpDetailList?.data?.current
                }}
                onChange={(pagination) => {
                    let { current, pageSize } = pagination
                    let newQueryForm = JSON.parse(JSON.stringify(queryForm))
                    newQueryForm.pageNum = current || newQueryForm.pageNum
                    newQueryForm.pageSize = pageSize || newQueryForm.pageSize
                    setQueryForm({ ...newQueryForm })
                }}
            />
        </Modal>}
    </>
};

export default React.memo(LoginIpDetails);